package com.sina.weibo.sdk.demo;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.text.SimpleDateFormat;
import java.util.LinkedList;
import java.util.List;

import org.apache.http.HttpResponse;
import org.apache.http.ParseException;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.HttpClient;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;
import org.json.JSONException;
import org.json.JSONObject;
import org.json.JSONTokener;

import android.app.Activity;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.view.Menu;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import com.sina.weibo.sdk.auth.Oauth2AccessToken;
import com.sina.weibo.sdk.auth.WeiboAuth;
import com.sina.weibo.sdk.auth.WeiboAuthListener;
import com.sina.weibo.sdk.exception.WeiboException;

public class MainActivity extends Activity {
	private static final String TAG = "MainActivity";

	/** 微博 Web 授权类，提供登陆等功能 */
	private WeiboAuth mWeiboAuth;

	/** 封装了 "access_token"，"expires_in"，"refresh_token"，并提供了他们的管理功能 */
	private Oauth2AccessToken mAccessToken;

	private TextView mTokenInfoTV;
	private EditText mMessageET;
	private Button mSendBtn;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		mWeiboAuth = new WeiboAuth(this, Constants.APP_KEY, Constants.REDIRECT_URL, Constants.SCOPE);

		mTokenInfoTV = (TextView) findViewById(R.id.textView_tokenInfo);
		mMessageET = (EditText) findViewById(R.id.editText_message);
		mSendBtn = (Button) findViewById(R.id.button_sendWeibo);

		// 获取Token
		findViewById(R.id.button_getToken).setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				mWeiboAuth.anthorize(new AuthListener());
			}
		});

		// 发送微博
		mMessageET.setVisibility(View.GONE);
		mSendBtn.setVisibility(View.GONE);
		mSendBtn.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				sendWeibo(mMessageET.getText().toString());
			}
		});
	}

	// 发送微博
	protected void sendWeibo(String string) {
		//组织post参数
		List<BasicNameValuePair> params = new LinkedList<BasicNameValuePair>();
		params.add(new BasicNameValuePair("status", string));
		params.add(new BasicNameValuePair("access_token", mAccessToken.getToken()));

		HttpClient httpClient = new DefaultHttpClient();
		
		//传入post方法的请求地址，即发送微博的api接口
		HttpPost postMethod = new HttpPost("https://api.weibo.com/2/statuses/update.json");
		try {
			postMethod.setEntity(new UrlEncodedFormEntity(params, "utf-8"));
			HttpResponse httpResponse = httpClient.execute(postMethod);

			//将返回结果转为字符串，通过文档可知返回结果为json字符串，结构请参考文档
			String resultStr=EntityUtils.toString(httpResponse.getEntity());
			Log.e(TAG, resultStr);
			
			//从json字符串中建立JSONObject
			JSONObject resultJson = new JSONObject(resultStr);
			
			//如果发送微博失败的话，返回字段中有"error"字段，通过判断是否存在该字段即可知道是否发送成功
			if (resultJson.has("error")) {
				Toast.makeText(this, "发送失败", Toast.LENGTH_SHORT).show();
			} else {
				Toast.makeText(this, "发送成功", Toast.LENGTH_SHORT).show();
			}

		} catch (UnsupportedEncodingException e) {
			Log.e(TAG, e.getLocalizedMessage());
		} catch (ClientProtocolException e) {
			Log.e(TAG, e.getLocalizedMessage());
		} catch (IOException e) {
			Log.e(TAG, e.getLocalizedMessage());
		} catch (ParseException e) {
			Log.e(TAG, e.getLocalizedMessage());
		} catch (JSONException e) {
			Log.e(TAG, e.getLocalizedMessage());
		}
	}

	//登录授权接口
	class AuthListener implements WeiboAuthListener {

		//登录成功
		@Override
		public void onComplete(Bundle values) {
			// 从 Bundle 中解析 Token
			mAccessToken = Oauth2AccessToken.parseAccessToken(values);
			if (mAccessToken.isSessionValid()) {
				// 显示 Token
				updateTokenView();

				// 显示发送微博的按钮和输入框
				mSendBtn.setVisibility(View.VISIBLE);
				mMessageET.setVisibility(View.VISIBLE);

				// 保存 Token 到 SharedPreferences
				// AccessTokenKeeper.writeAccessToken(MainActivity.this,
				// mAccessToken);
				Toast.makeText(MainActivity.this, "授权成功", Toast.LENGTH_SHORT).show();
			} else {
				// 当您注册的应用程序签名不正确时，就会收到 Code，请确保签名正确
				String code = values.getString("code");
				String message = "授权失败";
				if (!TextUtils.isEmpty(code)) {
					message = message + "\nObtained the code: " + code;
				}
				Toast.makeText(MainActivity.this, message, Toast.LENGTH_LONG).show();
			}
		}

		@Override
		public void onCancel() {
			Toast.makeText(MainActivity.this, "取消授权", Toast.LENGTH_LONG).show();
		}

		@Override
		public void onWeiboException(WeiboException e) {
			Toast.makeText(MainActivity.this, "Auth exception : " + e.getMessage(), Toast.LENGTH_LONG).show();
		}
	}

	//显示token信息
	private void updateTokenView() {
		String date = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss").format(new java.util.Date(mAccessToken
				.getExpiresTime()));
		String format = "Token：%1$s \n有效期：%2$s";
		mTokenInfoTV.setText(String.format(format, mAccessToken.getToken(), date));
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}

}
